/********************************************************                                                                 
script to get last medication taken by patients in cohort
last revised: 21 Apr 2021
authors: Haroun Chahed, Hui Xing Tan, Desmond Chun Hwee Teo
***********************************************************/

/*txlist:  40241331, 1310149, */ -- (21 Apr 2021: removed apixaban, dabigatran)

/***********************
Declare treatment lists
************************/

DECLARE @txList TABLE (Value INT) --txlist
INSERT INTO @txList 
SELECT tx FROM (VALUES (40241331),(1310149)) as tbl(tx);

IF OBJECT_ID('AF12mo_Starburst_final_drug_revised', 'U') IS NOT NULL
  DROP TABLE AF12mo_Starburst_final_drug_revised;

CREATE TABLE cdm.dbo.AF12mo_Starburst_final_drug_revised
(
	person_id bigint,
	drug_concept_id int,
	drug_final varchar(50)
);

WITH 

drugonly AS (
-- remove outcomes of interest under "drug_concept_id"
SELECT person_id
      ,drug_concept_id
      ,concept_name
      ,drug_seq
      ,startdate
  FROM cdm.dbo.AF12mo_drug_seq_0_B_revised
  WHERE drug_concept_id in (SELECT Value FROM @txList)
),

ranked_drugs AS (
-- create row number which to identify final drug in the sequence
SELECT drugonly.*, 
		ROW_NUMBER() OVER (PARTITION BY person_id ORDER BY drug_seq DESC) as rn
		FROM drugonly
)

INSERT INTO cdm.dbo.AF12mo_Starburst_final_drug_revised (person_id, drug_concept_id, drug_final)
(
SELECT	person_id, 
		drug_concept_id, 
		concept_name 
FROM ranked_drugs where rn = 1
)