/****************************************************************************************                                                                
script to get time to bleed in patients who experienced bleeding
last revised: 13 Apr 2021
authors: Haroun Chahed, Hui Xing Tan, Desmond Chun Hwee Teo
*****************************************************************************************/
/*******************************************************************************************************************************************
Note: This query is for further investigating the characteristics of our cohort in terms of the time from taking the anticoagulatnt to bleed
- Includes patients who have experienced bleeding, including those who had a clot first
- drug_concept_id gives you the concept_id of the anticoagulant
- time_to_bleed refers to the time between the start of the drug era and the condition occurrence (i.e. bleeding)
- RowNum refers to the sequence of the drug era, in descending order. To get info on the earliest drug era (which may or maynot be the same as 
the final drug used by the patient), filter for RowNum = 1 
*******************************************************************************************************************************************/

/*txlist:  40241331, 1310149*/
/*aspirin, NSAIDs, and antiplatelets: 1112807, 1115008, 1118084, 1124300, 1136980, 1146810, 1150345, 1177480, 1178663, 
1185922, 19011355, 19125195, 1322184, 1302398, 1331270, 40163718, 40241186, 1322199*/
/*outcomelist (bleed): 26727, 28779, 75043, 76784, 79864, 192671, 193795, 195321, 196442, 197018, 261687, 315276,376713, 432869, 432923, 433515, 434402, 436148, 436430, 437312, 438468, 439040, 439847, 443530, 4027729,
4049659, 4077201, 4077958, 4077959, 4078446, 4103703, 4108952, 4110185, 4110186, 4111708, 4111709, 4174044,
4176892, 4211001, 4218781, 4231580, 4232181, 4294973, 4317284, 4319328, 4326561, 40483641, 40492969*/

/**************************************************
Declare treatment, concurrent med and outcome lists
***************************************************/

DECLARE @txList TABLE (Value INT) --txlist
INSERT INTO @txList 
SELECT tx FROM (VALUES (40241331),(1310149)) as tbl(tx);

DECLARE @outcomeList_bleed TABLE (Value INT) --outcomelist (bleed)
INSERT INTO @outcomeList_bleed
SELECT ob FROM (VALUES (26727), (28779), (75043), (76784), (79864), (192671), (193795), (195321), (196442), (197018), (261687), (315276),
(376713), (432869), (432923), (433515), (434402), (436148), (436430), (437312), (438468), (439040), (439847), (443530), (4027729),
(4049659), (4077201), (4077958), (4077959), (4078446), (4103703), (4108952), (4110185), (4110186), (4111708), (4111709), (4174044),
(4176892), (4211001), (4218781), (4231580), (4232181), (4294973), (4317284), (4319328), (4326561), (40483641), (40492969)) as tbl(ob);

SELECT 
	af.person_id, af.index_year -- all columns from AF
	,
	ce.condition_concept_id, ce.condition_era_start_date, ce.condition_era_end_date -- selected columns from condition_occurrence
	,
	de.drug_concept_id, de.drug_era_start_date, de.drug_era_end_date, DATEDIFF(day, de.drug_era_start_date, de.drug_era_end_date) as drugera_duration -- selected columns from drug_exposure
	, 
	row_number() over (partition by af.person_id order by de.drug_era_start_date asc) as RowNum -- change to asc to calculate mean duration
	,
	DATEDIFF(day, de.drug_era_start_date, ce.condition_era_start_date) as time_to_bleed

FROM cdm.dbo.AF12mo_drug_seq_0_B_revised AS af
	
	INNER JOIN cdm.dbo.condition_era AS ce
		ON af.person_id = ce.person_id
		
	INNER JOIN cdm.dbo.drug_era AS de 
		ON af.person_id = de.person_id

WHERE
	de.drug_era_start_date < ce.condition_era_start_date 

		-- include only warfarin, rivaroxaban
		AND de.drug_concept_id IN (SELECT Value FROM @txList)
		
		 -- all bleeding-related concept IDs
		AND ce.condition_concept_id IN (SELECT Value FROM @outcomeList_bleed)

		-- select only drugs BEFORE bleed
		AND DATEDIFF(day, ce.condition_era_start_date, de.drug_era_start_date) <= 0 

		-- select the cases where the condition is the same as the bleeding event
		AND af.drug_concept_id in (SELECT Value FROM @outcomeList_bleed)
		AND ce.condition_era_start_date = af.startdate

ORDER BY af.person_id, de.drug_era_start_date