setwd("C:\\Users\\XXX\\Documents")

# R code for generating weighted effectiveness, safety plot

library(ggplot2)
library(readxl)
library(stringr)

# import data
df <- read_excel("./bleed_clots_first_occurrence.xlsx")
View(df)
#capitalise first letter of each drug and event
df$drug <- str_to_title(df$drug, locale="en")
df$event <- str_to_title(df$event, locale="en")

#get percentage of total
df$pct <-df$number/ave(df$number, df$drug, FUN=sum)

#convert pct to % scale
df$pct100 <- df$pct*100

#get width
df$width <-ave(df$number, df$drug, FUN=sum)

#define levels 
df$event<-factor(df$event, levels=c("Clot","No Event","Bleed"), 
                 labels=c("Thromboembolic Events","No Events","Bleeding Events"))

#define drug with sample size
df$drug_samplesize<-ave(df$number, df$drug, FUN=sum)
df$drug_withsamplesize<- paste(df$drug,"(n=",df$drug_samplesize,")")

#define labels with number and percentage
df$pctwithn<-paste(df$number,"\n(",format(round(df$pct100,1),nsmall=1),"%)")

#plot graph
ggplot(df, aes(x=drug_withsamplesize, y=pct100, fill=event, width=width)) +
  scale_y_continuous(breaks=c(0,20,40,60,80,100)) +
  geom_col() + 
  geom_text(aes(label=pctwithn), position = position_stack(vjust=.5), size=3) +
  facet_grid(drug ~.,scale="free_y", space="free") +
  labs(y="Proportion (%)", x="") +
  ggtitle("Relative Effectiveness, Safety and Utilisation (Singapore, n = 364)") +
  scale_fill_manual(name="", values=c("#A6D6E3","#D7DCDE","#f0b0a1")) +
  guides(fill = guide_legend(reverse=TRUE)) +
  theme_bw() +
  theme(plot.title = element_text(hjust = 0.5)) +
  theme(panel.border = element_blank()) +
  theme(strip.text.y = element_blank()) +
  theme(legend.position = "bottom") +
  coord_flip()

# save plot as 300dpi
ggsave("rplot_300dpi.png",units = "in", width=8, height=4, dpi=300)
