setwd("C:\\Users\\XXX\\Documents")

# R code for generating weighted effectiveness, safety plot

library(ggplot2)
library(readxl)
library(stringr)

# create function to plot data. Input parameters:
# -path of excel file generated from SQL (e.g."./bleed_clots_first_occurrence_3mths.xlsx")
# -title of plot (e.g. "Landmark analysis at 3 months")
# -subtitle of plot (e.g. "(Singapore, n = 364)")
# -legend position (e.g. "botton","NA")

ReUSEplot<- function(path, title, mysubtitle, legendpos){
  # import data
  df <- read_excel(path)
  View(df)
  #capitalise first letter of each drug and event
  df$drug <- str_to_title(df$drug, locale="en")
  df$event <- str_to_title(df$event, locale="en")
  
  #get percentage of total
  df$pct <-df$number/ave(df$number, df$drug, FUN=sum)
  
  #convert pct to % scale
  df$pct100 <- df$pct*100
  
  #get width
  df$width <-ave(df$number, df$drug, FUN=sum)
  
  #define levels 
  df$event<-factor(df$event, levels=c("Clot","No Event","Bleed"), 
                   labels=c("Thromboembolic Events","No Events","Bleeding Events"))
  
  #define drug with sample size
  df$drug_samplesize<-ave(df$number, df$drug, FUN=sum)
  df$drug_withsamplesize<- paste(df$drug,"(n=",df$drug_samplesize,")")
  
  #define labels with number and percentage
  df$pctwithn<-paste(df$number,"\n(",format(round(df$pct100,1),nsmall=1),"%)")
  
  #plot graph
  plot<- ggplot(df, aes(x=drug_withsamplesize, y=pct100, fill=event, width=width)) +
    scale_y_continuous(breaks=c(0,20,40,60,80,100)) +
    geom_col() + 
    geom_text(aes(label=pctwithn), position = position_stack(vjust=.5), size=3) +
    facet_grid(drug ~.,scale="free_y", space="free") +
    labs(y="Proportion (%)", x="") +
    labs(title=title, subtitle= mysubtitle, tag ="A") +
    scale_fill_manual(name="", values=c("#A6D6E3","#D7DCDE","#f0b0a1")) +
    guides(fill = guide_legend(reverse=TRUE)) +
    theme_bw() +
    theme(plot.title = element_text(hjust = 0.5, face = "bold", size =14)) +
    theme(plot.subtitle = element_text(hjust = 0.5, size =12)) +
    theme(panel.border = element_blank()) +
    theme(strip.text.y = element_blank()) +
    theme(legend.position = legendpos) +
    coord_flip()
  
  return(plot)
}

# Run function over different files to produce various plots
library("cowplot")
a<-ReUSEplot("./bleed_clots_first_occurrence.xlsx","\nTotal cohort follow up analysis","\nSingapore (n = 364)","NA")
c<-ReUSEplot("./bleed_clots_first_occurrence_3mths.xlsx","\nLandmark analysis at 3 months","\nSingapore (n = 364)","NA")
b<-ReUSEplot("./bleed_clots_first_occurrence_ajou.xlsx","","South Korea (n = 2055)","bottom")
d<-ReUSEplot("./bleed_clots_first_occurrence_3mths_ajou.xlsx","","South Korea (n = 2055)","bottom")


# Arrange the plots for display side-by-side
library("gridExtra")
library("grid")

a_label<-ggdraw(a) + draw_plot_label("A", x=.1, y=.85)
c_label<-ggdraw(c) + draw_plot_label("C", x=.1, y=.85)
b_label<-ggdraw(b) + draw_plot_label("B", x=.1, y=.95)
d_label<-ggdraw(d) + draw_plot_label("D", x=.1, y=.95)

grid_to_save<-grid.arrange(arrangeGrob(a_label, b_label,nrow = 2),  # First row with 2 plots in 2 different columns
             arrangeGrob(c_label, d_label, nrow = 2), # Second row with 2 plots in 2 different columns
             ncol = 2) # Number of rows


ggsave("ReUSE.png", grid_to_save, ,units = "in", width=16, height=8, dpi=500)

